@@ -25,9 +25,9 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py 3560 2008-02-11 17:35:26Z wwalker $"
-__version__   = "$Revision: 3560 $"
-__date__      = "$Date: 2008-02-11 12:35:26 -0500 (Mon, 11 Feb 2008) $"
+__id__        = "$Id: braille.py 3571 2008-02-12 23:27:57Z eitani $"
+__version__   = "$Revision: 3571 $"
+__date__      = "$Date: 2008-02-12 18:27:57 -0500 (Tue, 12 Feb 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -689,7 +689,8 @@ class ReviewComponent(Component):
         - zone: the flat review Zone associated with this component
         """
 
-        Component.__init__(self, accessible, string, cursorOffset)
+        Component.__init__(self, accessible, string,
+                           cursorOffset, expandOnCursor=True)
         self.zone = zone
 
 class ReviewText(Region):
